pub struct MessageBody { /* private fields */ }Expand description
Represents the message body, handling both raw and compressed forms.
Implementations
Sourceimpl MessageBody
impl MessageBody
Sourcepub fn from_compressed(raw: Bytes, compressed: Bytes) -> Self
pub fn from_compressed(raw: Bytes, compressed: Bytes) -> Self
Creates a message body with both raw and compressed data.
Sourcepub fn compressed(&self) -> Option<&Bytes>
pub fn compressed(&self) -> Option<&Bytes>
Returns the compressed body, if available.
Sourcepub fn compressed_mut(&mut self) -> &mut Option<Bytes>
pub fn compressed_mut(&mut self) -> &mut Option<Bytes>
Returns a mutable reference to the compressed body.
Sourcepub fn is_compressed(&self) -> bool
pub fn is_compressed(&self) -> bool
Returns whether the body is compressed.
Sourcepub fn into_bytes(self) -> Bytes
pub fn into_bytes(self) -> Bytes
Consumes and returns the raw bytes.