pub struct MessageExt {Show 15 fields
pub message: Message,
pub broker_name: CheetahString,
pub queue_id: i32,
pub store_size: i32,
pub queue_offset: i64,
pub sys_flag: i32,
pub born_timestamp: i64,
pub born_host: SocketAddr,
pub store_timestamp: i64,
pub store_host: SocketAddr,
pub msg_id: CheetahString,
pub commit_log_offset: i64,
pub body_crc: u32,
pub reconsume_times: i32,
pub prepared_transaction_offset: i64,
}Fields
message: Messagebroker_name: CheetahStringqueue_id: i32store_size: i32queue_offset: i64sys_flag: i32born_timestamp: i64born_host: SocketAddrstore_timestamp: i64store_host: SocketAddrmsg_id: CheetahStringcommit_log_offset: i64body_crc: u32reconsume_times: i32prepared_transaction_offset: i64Implementations
Sourceimpl MessageExt
impl MessageExt
pub fn socket_address_2_byte_buffer(ip: &SocketAddr) -> Bytes
pub fn born_host_bytes(&self) -> Bytes
pub fn born_store_bytes(&self) -> Bytes
pub fn topic(&self) -> &CheetahString
pub fn born_host(&self) -> SocketAddr
pub fn store_host(&self) -> SocketAddr
pub fn with_born_host_v6_flag(&mut self)
pub fn with_store_host_v6_flag(&mut self)
pub fn body(&self) -> Option<Bytes>
pub fn sys_flag(&self) -> i32
pub fn body_crc(&self) -> u32
pub fn queue_id(&self) -> i32
pub fn flag(&self) -> i32
pub fn message_inner(&self) -> &Message
pub fn broker_name(&self) -> &str
pub fn store_size(&self) -> i32
pub fn queue_offset(&self) -> i64
pub fn born_timestamp(&self) -> i64
pub fn store_timestamp(&self) -> i64
pub fn msg_id(&self) -> &CheetahString
pub fn commit_log_offset(&self) -> i64
pub fn reconsume_times(&self) -> i32
pub fn prepared_transaction_offset(&self) -> i64
pub fn set_message_inner(&mut self, message_inner: Message)
pub fn set_broker_name(&mut self, broker_name: CheetahString)
pub fn set_queue_id(&mut self, queue_id: i32)
pub fn set_store_size(&mut self, store_size: i32)
pub fn set_queue_offset(&mut self, queue_offset: i64)
pub fn set_sys_flag(&mut self, sys_flag: i32)
pub fn set_born_timestamp(&mut self, born_timestamp: i64)
pub fn set_born_host(&mut self, born_host: SocketAddr)
pub fn set_store_timestamp(&mut self, store_timestamp: i64)
pub fn set_store_host(&mut self, store_host: SocketAddr)
pub fn set_msg_id(&mut self, msg_id: CheetahString)
pub fn set_commit_log_offset(&mut self, commit_log_offset: i64)
pub fn set_body_crc(&mut self, body_crc: u32)
pub fn set_reconsume_times(&mut self, reconsume_times: i32)
pub fn set_prepared_transaction_offset( &mut self, prepared_transaction_offset: i64, )
pub fn properties(&self) -> &HashMap<CheetahString, CheetahString>
Methods from Deref<Target = Message>
pub fn set_keys(&mut self, keys: CheetahString)
pub fn clear_property(&mut self, name: impl Into<CheetahString>)
pub fn set_properties( &mut self, properties: HashMap<CheetahString, CheetahString>, )
pub fn get_property(&self, key: &CheetahString) -> Option<CheetahString>
pub fn body(&self) -> Option<Bytes>
pub fn flag(&self) -> i32
pub fn topic(&self) -> &CheetahString
pub fn properties(&self) -> &MessageProperties
pub fn transaction_id(&self) -> Option<&str>
pub fn get_transaction_id(&self) -> Option<&CheetahString>
pub fn is_wait_store_msg_ok(&self) -> bool
pub fn delay_time_level(&self) -> i32
pub fn set_delay_time_level(&mut self, level: i32)
pub fn get_user_property( &self, name: impl Into<CheetahString>, ) -> Option<CheetahString>
pub fn as_any(&self) -> &dyn Any
pub fn set_instance_id(&mut self, instance_id: impl Into<CheetahString>)
Sourcepub fn body_slice(&self) -> &[u8] ⓘ
pub fn body_slice(&self) -> &[u8] ⓘ
Returns the message body as a byte slice (borrows).
This is the recommended way to access the message body.
Returns the message tags.
Sourcepub fn message_flag(&self) -> MessageFlag
pub fn message_flag(&self) -> MessageFlag
Returns the message flag as a type-safe MessageFlag.
Sourcepub fn wait_store_msg_ok(&self) -> bool
pub fn wait_store_msg_ok(&self) -> bool
Returns whether to wait for store confirmation.
Sourcepub fn delay_level(&self) -> i32
pub fn delay_level(&self) -> i32
Returns the delay time level.
Sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
Returns the instance ID.