MessageFlag

Struct MessageFlag 

pub struct MessageFlag(/* private fields */);
Message flags as a type-safe bitflag.

Implementations

Source

impl MessageFlag

pub const NONE: Self

pub const COMPRESSED: Self

pub const MULTI_TAGS: Self

pub const TRANSACTION_PREPARED: Self

pub const TRANSACTION_COMMIT: Self

pub const TRANSACTION_ROLLBACK: Self

pub const fn empty() -> Self

Creates an empty flag (no bits set).

pub const fn from_bits(bits: i32) -> Self

Creates a new flag from raw value.

pub const fn bits(&self) -> i32

Returns the raw flag value.

pub const fn contains(&self, other: Self) -> bool

Checks if a flag is set.

pub fn insert(&mut self, other: Self)

Sets a flag.

pub fn remove(&mut self, other: Self)

Removes a flag.

pub fn is_compressed(&self) -> bool

Returns true if the compressed flag is set.

pub fn is_multi_tags(&self) -> bool

Returns true if the multi-tags flag is set.

pub fn is_transaction_prepared(&self) -> bool

Returns true if the transaction prepared flag is set.

pub fn is_transaction_commit(&self) -> bool

Returns true if the transaction commit flag is set.

pub fn is_transaction_rollback(&self) -> bool

Returns true if the transaction rollback flag is set.