pub struct MessageFlag(/* private fields */);Expand description
Message flags as a type-safe bitflag.
Implementations
Sourceimpl MessageFlag
impl MessageFlag
pub const NONE: Self
pub const COMPRESSED: Self
pub const MULTI_TAGS: Self
pub const TRANSACTION_PREPARED: Self
pub const TRANSACTION_COMMIT: Self
pub const TRANSACTION_ROLLBACK: Self
Sourcepub fn is_compressed(&self) -> bool
pub fn is_compressed(&self) -> bool
Returns true if the compressed flag is set.
Returns true if the multi-tags flag is set.
Sourcepub fn is_transaction_prepared(&self) -> bool
pub fn is_transaction_prepared(&self) -> bool
Returns true if the transaction prepared flag is set.
Sourcepub fn is_transaction_commit(&self) -> bool
pub fn is_transaction_commit(&self) -> bool
Returns true if the transaction commit flag is set.
Sourcepub fn is_transaction_rollback(&self) -> bool
pub fn is_transaction_rollback(&self) -> bool
Returns true if the transaction rollback flag is set.